<?php

/**
 * WordPress settings API demo class
 *
 * @author Tareq Hasan
 */
require_once dirname( __FILE__ ) . '/class.settings-api.php';

if ( ! class_exists('Akadalymentes_tema_valaszto_Settings' ) ):
class Akadalymentes_tema_valaszto_Settings {

    private $settings_api;

    function __construct() {
        $this->settings_api = new WeDevs_Settings_API;

        add_action( 'admin_init', array($this, 'admin_init') );
        add_action( 'admin_menu', array($this, 'admin_menu') );
    }

    function admin_init() {

        //set the settings
        $this->settings_api->set_sections( $this->sections() );
        $this->settings_api->set_fields( $this->fields() );

        //initialize settings
        $this->settings_api->admin_init();
    }

    function admin_menu() {
        add_menu_page('Akadalymentes téma választó', 'Akadálymentes', 'administrator', 'akadalymentes-theme-switcher', array($this, 'option_page'), plugins_url( '../assets/img/icon.png', __FILE__), '60.25');
    }

    function sections() {
        $sections = array(
            array(
                'id' => 'Akadalymentes_tema_valaszto',
                'title' => 'Téma választó beállításai',
            ),
            
        );
        return $sections;
    }


    /**
     * Returns all the settings fields
     *
     * @return array settings fields
     */
    function fields() {
        $settings_fields = array(
			//------------------------------------------------
			//      Basic Settings
			//------------------------------------------------
            'Akadalymentes_tema_valaszto' => array(
                array(
                    'name'              => 'engedelyezes',
                    'label'             => 'Engedélyezed az Akadálymentes funkciót?',
                    'desc'              => 'Pipáld be, ha engedélyezni szeretnéd',
                    'type'              => 'checkbox'
                ),
                array(
                    'name'              => 'sticky_bar_position',
                    'label'             => 'Sticky Bar Position',
                    'desc'              => 'If enabled.',
                    'type'              => 'radio',
                    'default'           => 'top',
                    'options'           =>  array(
                        'top'       =>  'Top',
                        'bottom'    =>  'Bottom'
                        )
                ),
                
                array(
                    'name'              => 'Normal_theme',
                    'label'             => 'Alap téma:',
                    'desc'              => 'Válaszd ki az alapértelmezett témát!',
                    'type'              => 'radio',
                    'options'           => $this->themes_list()
                ),
                
                
                array(
                    'name'              => 'Accessability_theme',
                    'label'             => 'Akadálymentes Téma',
                    'desc'              => 'Válaszd ki az akadálymentes témát!',
                    'type'              => 'radio',
                    'default'           => 'top',
                    'options'           => $this->themes_list()
                ),
                
                array(
                    'name'              => 'akadalymentes_felirat',
                    'label'             => 'Akadálymentes felírat',
                    'desc'              => 'Add meg, hogy mi jelenjen meg az Akadálymentes gomb alatt, mikor ráviszik az egeret!',
                    'default'           => 'Akadálymentesített verzió',
                    'type'              => 'text',
                ),
                
                array(
                    'name'              => 'normal_felirat',
                    'label'             => 'Normál felírat',
                    'desc'              => 'Add meg, hogy mi jelenjen meg az Normál gomb alatt, mikor ráviszik az egeret!',
                    'default'           => 'Vissza a normál verzióra',
                    'type'              => 'text',
                ),
                array(
                    'name'              => 'cookie_name',
                    'label'             => 'A használni kívánt süti neve',
                    'desc'              => 'Adja meg, hogy mi legyen az a név, amivel elmentjük a beállítást (szóköz helyett _ használjon)',
                    'default'           => 'akadalymentes_active_theme',
                    'type'              => 'text',
                ),
                array(
                    'name'              => 'hide_site_title',
                    'label'             => 'Hide Site Title?',
                    'desc'              => 'Check this to hide site title in \'Theme Switcher\' Sticky Bar',
                    'type'              => 'checkbox',
                ),

                array(
                    'name'              => 'hide_credit',
                    'label'             => 'Remove Developer Credit?',
                    'desc'              => 'Check this to hide developer credit from \'Theme Switcher\' Sticky Bar :-( ',
                    'type'              => 'checkbox',
                ),
                array(
                    'name'              => 'enable_shortcode',
                    'label'             => 'Enable Shortcode?',
                    'desc'              => 'Check this if you want to enable shortcode <code>[Akadalymentes_tema_valaszto]</code> that can be used in posts, pages, widgets or in template files.',
                    'type'              => 'checkbox',
                ),
                array(
                    'name'              => 'custom_css',
                    'label'             => 'Custom CSS',
                    'desc'              => 'Custom CSS',
                    'type'              => 'textarea',
                ),
            ),
           
        );

        return $settings_fields;
    }

    function option_page() {
        ?>
        <div class="wrap">
		
    		<div class="scroll-to-up-setting-page-title">
    			<h1><img class="close-icon" title="Close" src="<?php echo plugins_url( '../assets/img/icon.png', __FILE__ ); ?>"> Akadálymentes Téma Választó</h1>
    			<!-- <p class="description">"Scroll To Up" Plugin Settings Page</p> -->
    		</div>

    		<div class="akadalymentes-col-left">
    			<?php 
    			// $this->settings_api->show_navigation();
    			$this->settings_api->show_forms(); ?>
    		</div>

        </div>
        <style type="text/css">
        .akadalymentes-col-left{
            float: left;
            max-width: 760px;
            margin-right: 14px;
        }
        .akadalymentes-col-right{
            background: #fff none repeat scroll 0 0;
            border: 1px solid #ddd;
            border-radius: 2px;
            float: left;
            padding: 0 5px 5px;
            width: 320px;
        }
        </style>
    <?php
    }

    /**
     * Get all the pages
     *
     * @return array page names with key value pairs
     */
    function get_pages() {
        $pages = get_pages();
        $pages_options = array();
        if ( $pages ) {
            foreach ($pages as $page) {
                $pages_options[$page->ID] = $page->post_title;
            }
        }

        return $pages_options;
    }

    function themes_list(){
        $arg = array(
            'errors' => false,
            'allowed' => null,
            'blog_id' => 0
        );
        return wp_get_themes($arg);
    }
function current_theme(){
        $arg = array(
            'stylesheet' => null,
            'theme_root' => null
        );
        return wp_get_theme($arg);
    }
}
endif;


/**
 * Get the value of a settings field
 *
 * @param string $option settings field name
 * @param string $section the section name this field belongs to
 * @param string $default default text if it's not found
 * @return mixed
 */
function akadalymentes_get_option( $option, $section, $default = '' ) {
 
    $options = get_option( $section );
 
    if ( isset( $options[$option] ) ) {
        return $options[$option];
    }
 
    return $default;
}

new Akadalymentes_tema_valaszto_Settings;